@@ -8,9 +8,9 @@ from ansible.module_utils.basic import AnsibleModule
 def main() -> None:
     """Return the module instance."""
     return AnsibleModule(
-        argument_spec=dict(
-            data=dict(default=None),
-            path=dict(default=None, type=str),
-            file=dict(default=None, type=str),
-        )
+        argument_spec={
+            "data": {"default": None},
+            "path": {"default": None},
+            "file": {"default": None},
+        }
     )
