@@ -133,19 +133,13 @@ def initialize_options(arguments: list[str] | None = None) -> None:
 def _do_list(rules: RulesCollection) -> int:
     # On purpose lazy-imports to avoid pre-loading Ansible
     # pylint: disable=import-outside-toplevel
-    from ansiblelint.generate_docs import (
-        rules_as_docs,
-        rules_as_md,
-        rules_as_rich,
-        rules_as_str,
-    )
+    from ansiblelint.generate_docs import rules_as_md, rules_as_rich, rules_as_str
 
     if options.list_rules:
         _rule_format_map: dict[str, Callable[..., Any]] = {
             "brief": rules_as_str,
             "full": rules_as_rich,
             "md": rules_as_md,
-            "docs": rules_as_docs,
         }
 
         console.print(
@@ -381,7 +375,7 @@ def path_inject() -> None:
     # Expand ~ in PATH as it known to break many tools
     expanded = False
     for idx, path in enumerate(paths):
-        if "~" in path:  # pragma: no cover
+        if path.startswith("~"):  # pragma: no cover
             paths[idx] = os.path.expanduser(path)
             expanded = True
     if expanded:  # pragma: no cover
