@@ -3,7 +3,8 @@
 # Copyright (c) 2018, Ansible Project
 from __future__ import annotations
 
-from typing import TYPE_CHECKING, Generator
+from collections.abc import Generator
+from typing import TYPE_CHECKING
 
 from ansiblelint.errors import MatchError
 from ansiblelint.file_utils import Lintable
@@ -12,7 +13,6 @@ from ansiblelint.rules import AnsibleLintRule
 if TYPE_CHECKING:
     from typing import Any, Tuple
 
-    from ansiblelint.constants import odict
 
 META_STR_INFO = ("author", "description")
 META_INFO = tuple(
@@ -26,7 +26,7 @@ META_INFO = tuple(
 
 
 def _platform_info_errors_itr(
-    platforms: list[odict[str, str]],
+    platforms: list[dict[str, str]],
 ) -> Generator[str, None, None]:
     if not isinstance(platforms, list):
         yield "Platforms should be a list of dictionaries"
@@ -40,7 +40,7 @@ def _platform_info_errors_itr(
 
 
 def _galaxy_info_errors_itr(
-    galaxy_info: odict[str, Any],
+    galaxy_info: dict[str, Any],
     info_list: tuple[str, ...] = META_INFO,
     str_info_list: tuple[str, ...] = META_STR_INFO,
 ) -> Generator[str, None, None]:
@@ -66,15 +66,10 @@ class MetaMainHasInfoRule(AnsibleLintRule):
     tags = ["metadata"]
     version_added = "v4.0.0"
 
-    def matchplay(self, file: Lintable, data: odict[str, Any]) -> list[MatchError]:
+    def matchplay(self, file: Lintable, data: dict[str, Any]) -> list[MatchError]:
         if file.kind != "meta":
             return []
 
-        # since Ansible 2.10 we can add a meta/requirements.yml but
-        # we only want to match on meta/main.yml
-        if file.path.name != "main.yml":
-            return []
-
         galaxy_info = data.get("galaxy_info", False)
         if galaxy_info:
             return [
